Dataset
==================

User can use LPOT builtin datasets as well as register their own datasets.

## Builtin dataset support list

LPOT supports builtin dataloader on popular industry dataset. Please refer to 'examples/helloworld/tf_example1' about how to config a builtin dataloader.

#### TensorFlow

| Dataset | Parameters | Comments | Usage |
| :------ | :------ | :------ | :------ |
| MNIST(root, train, transform, filter, download) | **root** (str): Root directory of dataset <br> **train** (bool, default=False): If True, creates dataset from train subset, otherwise from validation subset <br> **transform** (transform object, default=None):  transform to process input data <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions <br> **download** (bool, default=True): If true, downloads the dataset from the internet and puts it in root directory. If dataset is already downloaded, it is not downloaded again. | If download is True, it will download dataset to root/MNIST/, otherwise user should put mnist.npz under root/MNIST/ manually. | **In yaml file:** <br> dataset: <br> &ensp;&ensp; MNIST: <br> &ensp;&ensp;&ensp;&ensp; root: /path/to/root <br> &ensp;&ensp;&ensp;&ensp; train: False <br> &ensp;&ensp;&ensp;&ensp; download: True <br> (transform and filter are not set in the range of dataset) <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['MNIST'] (root=root, train=False, transform=transform, filter=None, download=True) |
| FashionMNIST(root, train, transform, filter, download) | **root** (str): Root directory of dataset <br> **train**(bool, default=False): If True, creates dataset from train subset, otherwise from validation subset <br> **transform** (transform object, default=None):  transform to process input data <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions <br> **download** (bool, default=True): If true, downloads the dataset from the internet and puts it in root directory. If dataset is already downloaded, it is not downloaded again. | If download is True, it will download dataset to root/FashionMNIST/, otherwise user should put train-labels-idx1-ubyte.gz, train-images-idx3-ubyte.gz, t10k-labels-idx1-ubyte.gz and t10k-images-idx3-ubyte.gz under root/FashionMNIST/ manually.| **In yaml file:** <br> dataset: <br> &ensp;&ensp; FashionMNIST: <br> &ensp;&ensp;&ensp;&ensp; root: /path/to/root <br> &ensp;&ensp;&ensp;&ensp; train: False <br> &ensp;&ensp;&ensp;&ensp; download: True <br> (transform and filter are not set in the range of dataset) <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['FashionMNIST'] (root=root, train=False, transform=transform, filter=None, download=True) |
| CIFAR10(root, train, transform, filter, download) | **root** (str): Root directory of dataset <br> **train** (bool, default=False): If True, creates dataset from train subset, otherwise from validation subset <br> **transform** (transform object, default=None):  transform to process input data <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions <br> **download** (bool, default=True): If true, downloads the dataset from the internet and puts it in root directory. If dataset is already downloaded, it is not downloaded again. | If download is True, it will download dataset to root/ and extract it automatically, otherwise user can download file from https://www.cs.toronto.edu/~kriz/cifar-10-python.tar.gz manually to root/ and extract it. | **In yaml file:** <br> dataset: <br> &ensp;&ensp; CIFAR10: <br> &ensp;&ensp;&ensp;&ensp; root: /path/to/root <br> &ensp;&ensp;&ensp;&ensp; train: False <br> &ensp;&ensp;&ensp;&ensp; download: True <br> (transform and filter are not set in the range of dataset) <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['CIFAR10'] (root=root, train=False, transform=transform, filter=None, download=True) |
| CIFAR100(root, train, transform, filter, download) | **root** (str): Root directory of dataset <br> **train** (bool, default=False): If True, creates dataset from train subset, otherwise from validation subset <br> **transform** (transform object, default=None):  transform to process input data <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions <br> **download** (bool, default=True): If true, downloads the dataset from the internet and puts it in root directory. If dataset is already downloaded, it is not downloaded again. | If download is True, it will download dataset to root/ and extract it automatically, otherwise user can download file from https://www.cs.toronto.edu/~kriz/cifar-100-python.tar.gz manually to root/ and extract it. | **In yaml file:** <br> dataset: <br> &ensp;&ensp; CIFAR100: <br> &ensp;&ensp;&ensp;&ensp; root: /path/to/root <br> &ensp;&ensp;&ensp;&ensp; train: False <br> &ensp;&ensp;&ensp;&ensp; download: True <br> (transform and filter are not set in the range of dataset) <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['CIFAR100'] (root=root, train=False, transform=transform, filter=None, download=True) |
| ImageRecord(root, transform, filter) | **root** (str): Root directory of dataset <br> **transform** (transform object, default=None):  transform to process input data <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions | Please arrange data in this way: <br> root/validation-000-of-100 <br> root/validation-001-of-100 <br> ... <br> root/validation-099-of-100 <br> The file name needs to follow this pattern: '* - * -of- *' | **In yaml file:** <br> dataset: <br> &ensp;&ensp; ImageRecord: <br> &ensp;&ensp;&ensp;&ensp; root: /path/to/root <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['ImageRecord'] (root=root, transform=transform, filter=None) |
| ImageFolder(root, transform, filter) | **root** (str): Root directory of dataset <br> **transform** (transform object, default=None):  transform to process input data <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions | Please arrange data in this way: <br> root/class_1/xxx.png <br> root/class_1/xxy.png <br> root/class_1/xxz.png <br> ... <br> root/class_n/123.png <br> root/class_n/nsdf3.png <br> root/class_n/asd932_.png <br> Please put images of different categories into different folders. | **In yaml file:** <br> dataset: <br> &ensp;&ensp; ImageFolder: <br> &ensp;&ensp;&ensp;&ensp; root: /path/to/root <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['ImageFolder'] (root=root,transform=transform, filter=None) |
| ImagenetRaw(data_path, image_list, transform, filter) | **data_path** (str): Root directory of dataset <br> **image_list** (str): data file, record image_names and their labels <br> **transform** (transform object, default=None):  transform to process input data <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions | Please arrange data in this way: <br> data_path/img1.jpg <br> data_path/img2.jpg <br> ... <br> data_path/imgx.jpg <br> dataset will read name and label of each image from image_list file, if user set image_list to None, it will read from data_path/val_map.txt automatically. | **In yaml file:** <br> dataset: <br> &ensp;&ensp; ImagenetRaw: <br> &ensp;&ensp;&ensp;&ensp; data_path: /path/to/image <br> &ensp;&ensp;&ensp;&ensp; image_list: /path/to/label <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['ImagenetRaw'] (data_path, image_list, transform=transform, filter=None) |
| COCORecord(root, num_cores, transform, filter) | **root** (str): Root directory of dataset <br> **num_cores** (int, default=28):The number of input Datasets to interleave from in parallel <br> **transform** (transform object, default=None):  transform to process input data <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions | Root is a full path to tfrecord file, which contains the file name. <br> **COCORecord just supports batch_size=1** | **In yaml file:** <br> dataset: <br> &ensp;&ensp; COCORecord: <br> &ensp;&ensp; root: /path/to/tfrecord <br> &ensp;&ensp; num_cores: 28 <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['COCORecord'] (root, num_cores=28, transform=transform, filter=None) |
| COCORaw(root, img_dir, anno_dir, transform, filter) | **root** (str): Root directory of dataset <br> **img_dir** (str, default='val2017'): image file directory <br> **anno_dir** (str, default='annotations/instances_val2017.json'): annotation file directory <br> **transform** (transform object, default=None):  transform to process input data <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions | Please arrange data in this way: <br> /root/img_dir/1.jpg <br> /root/img_dir/2.jpg <br> ... <br> /root/img_dir/n.jpg <br> /root/anno_dir <br> **Now COCORaw just supports batch_size=1** | **In yaml file:** <br> dataset: <br> &ensp;&ensp; COCORaw: <br> &ensp;&ensp;&ensp;&ensp; root: /path/to/root <br> &ensp;&ensp; img_dir: /path/to/image <br> &ensp;&ensp; anno_dir: /path/to/annotation <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['COCORaw'] (root, img_dir, anno_dir, transform=transform, filter=None) <br> If anno_dir is not set, the dataset will use default label map |
| dummy(shape, low, high, dtype, label, transform, filter) | **shape** (list or tuple):support create multi shape tensors, use list of tuples for each tuple in the list, will create a such size tensor. <br> **low** (list or float, default=-128.):low out the tensor value range from[0, 1] to [0, low] or [low, 0] if low < 0, if float, will implement all tensors with same low value. <br> **high** (list or float, default=127.):high the tensor value by add all tensor element value high. If list, length of list should be same with shape list <br> **dtype** (list or str, default='float32'):support multi tensor dtype setting. If list, length of list should be same with shape list, if str, all tensors will use same dtype. dtype support 'float32', 'float16', 'uint8', 'int8', 'int32', 'int64', 'bool' <br> **label** (bool, default=False):whether to return 0 as label <br> **transform** (transform object, default=None): dummy dataset does not need transform. If transform is not None, it will ignore it. <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions | This dataset is to construct a dataset from a specific shape, the value range is calculated from: low * stand_normal(0, 1) + high. | **In yaml file:** <br> dataset: <br> &ensp;&ensp; dummy: <br> &ensp;&ensp;&ensp;&ensp; shape: [3, 224, 224, 3] <br> &ensp;&ensp;&ensp;&ensp; low: 0.0 <br> &ensp;&ensp;&ensp;&ensp; high: 127.0 <br> &ensp;&ensp;&ensp;&ensp; dtype: float32 <br> &ensp;&ensp;&ensp;&ensp; label: False <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['dummy'] (shape, low, high, dtype, label, transform=None, filter=None) |
| style_transfer(content_folder, style_folder, crop_ratio, resize_shape, image_format, transform, filter) | **content_folder** (str):Root directory of content images <br> **style_folder** (str):Root directory of style images <br> **crop_ratio** (float, default=0.1):cropped ratio to each side <br> **resize_shape** (tuple, default=(256, 256)):target size of image <br> **image_format** (str, default='jpg'): target image format <br> **transform** (transform object, default=None):  transform to process input data <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions | Dataset used for style transfer task. This Dataset is to construct a dataset from two specific image holders representing content image folder and style image folder. | **In yaml file:** <br> dataset: <br> &ensp;&ensp; style_transfer: <br> &ensp;&ensp;&ensp;&ensp; content_folder: /path/to/content_folder <br> &ensp;&ensp;&ensp;&ensp; style_folder: /path/to/style_folder <br> &ensp;&ensp;&ensp;&ensp; crop_ratio: 0.1 <br> &ensp;&ensp;&ensp;&ensp; resize_shape: [256, 256] <br> &ensp;&ensp;&ensp;&ensp; image_format: 'jpg' <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['style_transfer'] (content_folder, style_folder, crop_ratio, resize_shape, image_format, transform=transform, filter=None) |
| TFRecordDataset(root, compression_type, buffer_size, num_parallel_reads, transform, filter) | **root** (str): filename of dataset <br> **compression_type** (str, default=None):compression type, support "" (no compression), "ZLIB", or "GZIP". <br> **buffer_size** (int, default=None): the number of bytes in the read buffer <br> **num_parallel_reads** (tint, default=None): the number of files to read in parallel <br> **transform** (transform object, default=None):  transform to process input data <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions |Root is a full path to tfrecord file, which contains the file name. | **In yaml file:** <br> dataset: <br> &ensp;&ensp; TFRecordDataset: <br> &ensp;&ensp;&ensp;&ensp; root: /path/to/tfrecord <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['TFRecordDataset'] (root, transform=transform) |
| bert(root, label_file, task, transform, filter) | **root** (str): path of dataset <br> **label_file** (str): path of label file <br> **task** (str, default='squad'): task type of model <br> **transform** (transform object, default=None):  transform to process input data <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions | This dataset supports tfrecord data, please refer to [Guide](../examples/tensorflow/nlp/bert/README.md) to create tfrecord file first. | **In yaml file:** <br> dataset: <br> &ensp;&ensp; bert: <br> &ensp;&ensp; root: /path/to/root <br> &ensp;&ensp; label_file: /path/to/label_file <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['bert'] (root, label_file, transform=transform) | 

#### PyTorch

| Dataset | Parameters | Comments | Usage |
| :------ | :------ | :------ | :------ |
| MNIST(root, train, transform, filter, download) | **root** (str): Root directory of dataset <br> **train** (bool, default=False): If True, creates dataset from train subset, otherwise from validation subset <br> **transform** (transform object, default=None):  transform to process input data <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions <br> **download** (bool, default=True): If true, downloads the dataset from the internet and puts it in root directory. If dataset is already downloaded, it is not downloaded again. | If download is True, it will download dataset to root/MNIST/, otherwise user should put mnist.npz under root/MNIST/ manually. | **In yaml file:** <br> dataset: <br> &ensp;&ensp; MNIST: <br> &ensp;&ensp;&ensp;&ensp; root: /path/to/root <br> &ensp;&ensp;&ensp;&ensp; train: False <br> &ensp;&ensp;&ensp;&ensp; download: True <br> (transform and filter are not set in the range of dataset) <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['MNIST'] (root=root, train=False, transform=transform, filter=None, download=True) |
| FashionMNIST(root, train, transform, filter, download) | **root** (str): Root directory of dataset <br> **train**(bool, default=False): If True, creates dataset from train subset, otherwise from validation subset <br> **transform** (transform object, default=None):  transform to process input data <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions <br> **download** (bool, default=True): If true, downloads the dataset from the internet and puts it in root directory. If dataset is already downloaded, it is not downloaded again. | If download is True, it will download dataset to root/FashionMNIST/, otherwise user should put train-labels-idx1-ubyte.gz, train-images-idx3-ubyte.gz, t10k-labels-idx1-ubyte.gz and t10k-images-idx3-ubyte.gz under root/FashionMNIST/ manually.| **In yaml file:** <br> dataset: <br> &ensp;&ensp; FashionMNIST: <br> &ensp;&ensp;&ensp;&ensp; root: /path/to/root <br> &ensp;&ensp;&ensp;&ensp; train: False <br> &ensp;&ensp;&ensp;&ensp; download: True <br> (transform and filter are not set in the range of dataset) <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['FashionMNIST'] (root=root, train=False, transform=transform, filter=None, download=True) |
| CIFAR10(root, train, transform, filter, download) | **root** (str): Root directory of dataset <br> **train** (bool, default=False): If True, creates dataset from train subset, otherwise from validation subset <br> **transform** (transform object, default=None):  transform to process input data <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions <br> **download** (bool, default=True): If true, downloads the dataset from the internet and puts it in root directory. If dataset is already downloaded, it is not downloaded again. | If download is True, it will download dataset to root/ and extract it automatically, otherwise user can download file from https://www.cs.toronto.edu/~kriz/cifar-10-python.tar.gz manually to root/ and extract it. | **In yaml file:** <br> dataset: <br> &ensp;&ensp; CIFAR10: <br> &ensp;&ensp;&ensp;&ensp; root: /path/to/root <br> &ensp;&ensp;&ensp;&ensp; train: False <br> &ensp;&ensp;&ensp;&ensp; download: True <br> (transform and filter are not set in the range of dataset) <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['CIFAR10'] (root=root, train=False, transform=transform, filter=None, download=True) |
| CIFAR100(root, train, transform, filter, download) | **root** (str): Root directory of dataset <br> **train** (bool, default=False): If True, creates dataset from train subset, otherwise from validation subset <br> **transform** (transform object, default=None):  transform to process input data <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions <br> **download** (bool, default=True): If true, downloads the dataset from the internet and puts it in root directory. If dataset is already downloaded, it is not downloaded again. | If download is True, it will download dataset to root/ and extract it automatically, otherwise user can download file from https://www.cs.toronto.edu/~kriz/cifar-100-python.tar.gz manually to root/ and extract it. | **In yaml file:** <br> dataset: <br> &ensp;&ensp; CIFAR100: <br> &ensp;&ensp;&ensp;&ensp; root: /path/to/root <br> &ensp;&ensp;&ensp;&ensp; train: False <br> &ensp;&ensp;&ensp;&ensp; download: True <br> (transform and filter are not set in the range of dataset) <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['CIFAR100'] (root=root, train=False, transform=transform, filter=None, download=True) |
| ImageFolder(root, transform, filter) | **root** (str): Root directory of dataset <br> **transform** (transform object, default=None):  transform to process input data <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions | Please arrange data in this way: <br> root/class_1/xxx.png <br> root/class_1/xxy.png <br> root/class_1/xxz.png <br> ... <br> root/class_n/123.png <br> root/class_n/nsdf3.png <br> root/class_n/asd932_.png <br> Please put images of different categories into different folders. | **In yaml file:** <br> dataset: <br> &ensp;&ensp; ImageFolder: <br> &ensp;&ensp;&ensp;&ensp; root: /path/to/root <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['ImageFolder'] (root=root,transform=transform, filter=None) |
| ImagenetRaw(data_path, image_list, transform, filter) | **data_path** (str): Root directory of dataset <br> **image_list** (str): data file, record image_names and their labels <br> **transform** (transform object, default=None):  transform to process input data <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions | Please arrange data in this way: <br> data_path/img1.jpg <br> data_path/img2.jpg <br> ... <br> data_path/imgx.jpg <br> dataset will read name and label of each image from image_list file, if user set image_list to None, it will read from data_path/val_map.txt automatically. | **In yaml file:** <br> dataset: <br> &ensp;&ensp; ImagenetRaw: <br> &ensp;&ensp;&ensp;&ensp; data_path: /path/to/image <br> &ensp;&ensp;&ensp;&ensp; image_list: /path/to/label <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['ImagenetRaw'] (data_path, image_list, transform=transform, filter=None) |
| COCORaw(root, img_dir, anno_dir, transform, filter) | **root** (str): Root directory of dataset <br> **img_dir** (str, default='val2017'): image file directory <br> **anno_dir** (str, default='annotations/instances_val2017.json'): annotation file directory <br> **transform** (transform object, default=None):  transform to process input data <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions | Please arrange data in this way: <br> /root/img_dir/1.jpg <br> /root/img_dir/2.jpg <br> ... <br> /root/img_dir/n.jpg <br> /root/anno_dir <br> **Now COCORaw just supports batch_size=1**| **In yaml file:** <br> dataset: <br> &ensp;&ensp; COCORaw: <br> &ensp;&ensp;&ensp;&ensp; root: /path/to/root <br> &ensp;&ensp; img_dir: /path/to/image <br> &ensp;&ensp; anno_dir: /path/to/annotation <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['COCORaw'] (root, img_dir, anno_dir, transform=transform, filter=None) <br> If anno_dir is not set, the dataset will use default label map |
| dummy(shape, low, high, dtype, label, transform, filter) | **shape** (list or tuple):support create multi shape tensors, use list of tuples for each tuple in the list, will create a such size tensor. <br> **low** (list or float, default=-128.):low out the tensor value range from[0, 1] to [0, low] or [low, 0] if low < 0, if float, will implement all tensors with same low value. <br> **high** (list or float, default=127.):high the tensor value by add all tensor element value high. If list, length of list should be same with shape list <br> **dtype** (list or str, default='float32'):support multi tensor dtype setting. If list, length of list should be same with shape list, if str, all tensors will use same dtype. dtype support 'float32', 'float16', 'uint8', 'int8', 'int32', 'int64', 'bool' <br> **label** (bool, default=False):whether to return 0 as label <br> **transform** (transform object, default=None): dummy dataset does not need transform. If transform is not None, it will ignore it. <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions | This dataset is to construct a dataset from a specific shape, the value range is calculated from: low * stand_normal(0, 1) + high. | **In yaml file:** <br> dataset: <br> &ensp;&ensp; dummy: <br> &ensp;&ensp;&ensp;&ensp; shape: [3, 224, 224, 3] <br> &ensp;&ensp;&ensp;&ensp; low: 0.0 <br> &ensp;&ensp;&ensp;&ensp; high: 127.0 <br> &ensp;&ensp;&ensp;&ensp; dtype: float32 <br> &ensp;&ensp;&ensp;&ensp; label: False <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['dummy'] (shape, low, high, dtype, label, transform=None, filter=None) |
| bert(dataset, task, model_type, transform, filter) | **dataset** (list): list of data <br> **task** (str): the task of the model, support "classifier", "squad" <br> **model_type** (str, default='bert'): model type, support 'distilbert', 'bert', 'xlnet', 'xlm' <br> **transform** (transform object, default=None):  transform to process input data <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions | This Dataset is to construct from the Bert TensorDataset and not a full implementation from yaml config. The original repo link is: https://github.com/huggingface/transformers. When you want use this Dataset, you should add it before you initialize your DataLoader. | **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['bert'](dataset, task, model_type, transform=transform, filter=None) <br> Now not support yaml implementation |

#### MXNet

| Dataset | Parameters | Comments | Usage |
| :------ | :------ | :------ | :------ |
| MNIST(root, train, transform, filter, download) | **root** (str): Root directory of dataset <br> **train** (bool, default=False): If True, creates dataset from train subset, otherwise from validation subset <br> **transform** (transform object, default=None):  transform to process input data <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions <br> **download** (bool, default=True): If true, downloads the dataset from the internet and puts it in root directory. If dataset is already downloaded, it is not downloaded again. | If download is True, it will download dataset to root/MNIST/, otherwise user should put mnist.npz under root/MNIST/ manually. | **In yaml file:** <br> dataset: <br> &ensp;&ensp; MNIST: <br> &ensp;&ensp;&ensp;&ensp; root: /path/to/root <br> &ensp;&ensp;&ensp;&ensp; train: False <br> &ensp;&ensp;&ensp;&ensp; download: True <br> (transform and filter are not set in the range of dataset) <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['MNIST'] (root=root, train=False, transform=transform, filter=None, download=True) |
| FashionMNIST(root, train, transform, filter, download) | **root** (str): Root directory of dataset <br> **train**(bool, default=False): If True, creates dataset from train subset, otherwise from validation subset <br> **transform** (transform object, default=None):  transform to process input data <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions <br> **download** (bool, default=True): If true, downloads the dataset from the internet and puts it in root directory. If dataset is already downloaded, it is not downloaded again. | If download is True, it will download dataset to root/FashionMNIST/, otherwise user should put train-labels-idx1-ubyte.gz, train-images-idx3-ubyte.gz, t10k-labels-idx1-ubyte.gz and t10k-images-idx3-ubyte.gz under root/FashionMNIST/ manually.| **In yaml file:** <br> dataset: <br> &ensp;&ensp; FashionMNIST: <br> &ensp;&ensp;&ensp;&ensp; root: /path/to/root <br> &ensp;&ensp;&ensp;&ensp; train: False <br> &ensp;&ensp;&ensp;&ensp; download: True <br> (transform and filter are not set in the range of dataset) <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['FashionMNIST'] (root=root, train=False, transform=transform, filter=None, download=True) |
| CIFAR10(root, train, transform, filter, download) | **root** (str): Root directory of dataset <br> **train** (bool, default=False): If True, creates dataset from train subset, otherwise from validation subset <br> **transform** (transform object, default=None):  transform to process input data <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions <br> **download** (bool, default=True): If true, downloads the dataset from the internet and puts it in root directory. If dataset is already downloaded, it is not downloaded again. | If download is True, it will download dataset to root/ and extract it automatically, otherwise user can download file from https://www.cs.toronto.edu/~kriz/cifar-10-python.tar.gz manually to root/ and extract it. | **In yaml file:** <br> dataset: <br> &ensp;&ensp; CIFAR10: <br> &ensp;&ensp;&ensp;&ensp; root: /path/to/root <br> &ensp;&ensp;&ensp;&ensp; train: False <br> &ensp;&ensp;&ensp;&ensp; download: True <br> (transform and filter are not set in the range of dataset) <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['CIFAR10'] (root=root, train=False, transform=transform, filter=None, download=True) |
| CIFAR100(root, train, transform, filter, download) | **root** (str): Root directory of dataset <br> **train** (bool, default=False): If True, creates dataset from train subset, otherwise from validation subset <br> **transform** (transform object, default=None):  transform to process input data <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions <br> **download** (bool, default=True): If true, downloads the dataset from the internet and puts it in root directory. If dataset is already downloaded, it is not downloaded again. | If download is True, it will download dataset to root/ and extract it automatically, otherwise user can download file from https://www.cs.toronto.edu/~kriz/cifar-100-python.tar.gz manually to root/ and extract it. | **In yaml file:** <br> dataset: <br> &ensp;&ensp; CIFAR100: <br> &ensp;&ensp;&ensp;&ensp; root: /path/to/root <br> &ensp;&ensp;&ensp;&ensp; train: False <br> &ensp;&ensp;&ensp;&ensp; download: True <br> (transform and filter are not set in the range of dataset) <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['CIFAR100'] (root=root, train=False, transform=transform, filter=None, download=True) |
| ImageFolder(root, transform, filter) | **root** (str): Root directory of dataset <br> **transform** (transform object, default=None):  transform to process input data <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions | Please arrange data in this way: <br> root/class_1/xxx.png <br> root/class_1/xxy.png <br> root/class_1/xxz.png <br> ... <br> root/class_n/123.png <br> root/class_n/nsdf3.png <br> root/class_n/asd932_.png <br> Please put images of different categories into different folders. | **In yaml file:** <br> dataset: <br> &ensp;&ensp; ImageFolder: <br> &ensp;&ensp;&ensp;&ensp; root: /path/to/root <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['ImageFolder'] (root=root,transform=transform, filter=None) |
| ImagenetRaw(data_path, image_list, transform, filter) | **data_path** (str): Root directory of dataset <br> **image_list** (str): data file, record image_names and their labels <br> **transform** (transform object, default=None):  transform to process input data <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions | Please arrange data in this way: <br> data_path/img1.jpg <br> data_path/img2.jpg <br> ... <br> data_path/imgx.jpg <br> dataset will read name and label of each image from image_list file, if user set image_list to None, it will read from data_path/val_map.txt automatically. | **In yaml file:** <br> dataset: <br> &ensp;&ensp; ImagenetRaw: <br> &ensp;&ensp;&ensp;&ensp; data_path: /path/to/image <br> &ensp;&ensp;&ensp;&ensp; image_list: /path/to/label <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['ImagenetRaw'] (data_path, image_list, transform=transform, filter=None) |
| COCORaw(root, img_dir, anno_dir, transform, filter) | **root** (str): Root directory of dataset <br> **img_dir** (str, default='val2017'): image file directory <br> **anno_dir** (str, default='annotations/instances_val2017.json'): annotation file directory <br> **transform** (transform object, default=None):  transform to process input data <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions | Please arrange data in this way: <br> /root/img_dir/1.jpg <br> /root/img_dir/2.jpg <br> ... <br> /root/img_dir/n.jpg <br> /root/anno_dir <br> **Now COCORaw just supports batch_size=1**| **In yaml file:** <br> dataset: <br> &ensp;&ensp; COCORaw: <br> &ensp;&ensp;&ensp;&ensp; root: /path/to/root <br> &ensp;&ensp; img_dir: /path/to/image <br> &ensp;&ensp; anno_dir: /path/to/annotation <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['COCORaw'] (root, img_dir, anno_dir, transform=transform, filter=None) <br> If anno_dir is not set, the dataset will use default label map |
| dummy(shape, low, high, dtype, label, transform, filter) | **shape** (list or tuple):support create multi shape tensors, use list of tuples for each tuple in the list, will create a such size tensor. <br> **low** (list or float, default=-128.):low out the tensor value range from[0, 1] to [0, low] or [low, 0] if low < 0, if float, will implement all tensors with same low value. <br> **high** (list or float, default=127.):high the tensor value by add all tensor element value high. If list, length of list should be same with shape list <br> **dtype** (list or str, default='float32'):support multi tensor dtype setting. If list, length of list should be same with shape list, if str, all tensors will use same dtype. dtype support 'float32', 'float16', 'uint8', 'int8', 'int32', 'int64', 'bool' <br> **label** (bool, default=False):whether to return 0 as label <br> **transform** (transform object, default=None): dummy dataset does not need transform. If transform is not None, it will ignore it. <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions | This dataset is to construct a dataset from a specific shape, the value range is calculated from: low * stand_normal(0, 1) + high. | **In yaml file:** <br> dataset: <br> &ensp;&ensp; dummy: <br> &ensp;&ensp;&ensp;&ensp; shape: [3, 224, 224, 3] <br> &ensp;&ensp;&ensp;&ensp; low: 0.0 <br> &ensp;&ensp;&ensp;&ensp; high: 127.0 <br> &ensp;&ensp;&ensp;&ensp; dtype: float32 <br> &ensp;&ensp;&ensp;&ensp; label: False <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['dummy'] (shape, low, high, dtype, label, transform=None, filter=None) |

#### ONNXRT

| Dataset | Parameters | Comments | Usage |
| :------ | :------ | :------ | :------ |
| MNIST(root, train, transform, filter, download) | **root** (str): Root directory of dataset <br> **train** (bool, default=False): If True, creates dataset from train subset, otherwise from validation subset <br> **transform** (transform object, default=None):  transform to process input data <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions <br> **download** (bool, default=True): If true, downloads the dataset from the internet and puts it in root directory. If dataset is already downloaded, it is not downloaded again. | If download is True, it will download dataset to root/MNIST/, otherwise user should put mnist.npz under root/MNIST/ manually. | **In yaml file:** <br> dataset: <br> &ensp;&ensp; MNIST: <br> &ensp;&ensp;&ensp;&ensp; root: /path/to/root <br> &ensp;&ensp;&ensp;&ensp; train: False <br> &ensp;&ensp;&ensp;&ensp; download: True <br> (transform and filter are not set in the range of dataset) <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['MNIST'] (root=root, train=False, transform=transform, filter=None, download=True) |
| FashionMNIST(root, train, transform, filter, download) | **root** (str): Root directory of dataset <br> **train**(bool, default=False): If True, creates dataset from train subset, otherwise from validation subset <br> **transform** (transform object, default=None):  transform to process input data <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions <br> **download** (bool, default=True): If true, downloads the dataset from the internet and puts it in root directory. If dataset is already downloaded, it is not downloaded again. | If download is True, it will download dataset to root/FashionMNIST/, otherwise user should put train-labels-idx1-ubyte.gz, train-images-idx3-ubyte.gz, t10k-labels-idx1-ubyte.gz and t10k-images-idx3-ubyte.gz under root/FashionMNIST/ manually.| **In yaml file:** <br> dataset: <br> &ensp;&ensp; FashionMNIST: <br> &ensp;&ensp;&ensp;&ensp; root: /path/to/root <br> &ensp;&ensp;&ensp;&ensp; train: False <br> &ensp;&ensp;&ensp;&ensp; download: True <br> (transform and filter are not set in the range of dataset) <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['FashionMNIST'] (root=root, train=False, transform=transform, filter=None, download=True) |
| CIFAR10(root, train, transform, filter, download) | **root** (str): Root directory of dataset <br> **train** (bool, default=False): If True, creates dataset from train subset, otherwise from validation subset <br> **transform** (transform object, default=None):  transform to process input data <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions <br> **download** (bool, default=True): If true, downloads the dataset from the internet and puts it in root directory. If dataset is already downloaded, it is not downloaded again. | If download is True, it will download dataset to root/ and extract it automatically, otherwise user can download file from https://www.cs.toronto.edu/~kriz/cifar-10-python.tar.gz manually to root/ and extract it. | **In yaml file:** <br> dataset: <br> &ensp;&ensp; CIFAR10: <br> &ensp;&ensp;&ensp;&ensp; root: /path/to/root <br> &ensp;&ensp;&ensp;&ensp; train: False <br> &ensp;&ensp;&ensp;&ensp; download: True <br> (transform and filter are not set in the range of dataset) <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['CIFAR10'] (root=root, train=False, transform=transform, filter=None, download=True) |
| CIFAR100(root, train, transform, filter, download) | **root** (str): Root directory of dataset <br> **train** (bool, default=False): If True, creates dataset from train subset, otherwise from validation subset <br> **transform** (transform object, default=None):  transform to process input data <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions <br> **download** (bool, default=True): If true, downloads the dataset from the internet and puts it in root directory. If dataset is already downloaded, it is not downloaded again. | If download is True, it will download dataset to root/ and extract it automatically, otherwise user can download file from https://www.cs.toronto.edu/~kriz/cifar-100-python.tar.gz manually to root/ and extract it. | **In yaml file:** <br> dataset: <br> &ensp;&ensp; CIFAR100: <br> &ensp;&ensp;&ensp;&ensp; root: /path/to/root <br> &ensp;&ensp;&ensp;&ensp; train: False <br> &ensp;&ensp;&ensp;&ensp; download: True <br> (transform and filter are not set in the range of dataset) <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['CIFAR100'] (root=root, train=False, transform=transform, filter=None, download=True) |
| ImageFolder(root, transform, filter) | **root** (str): Root directory of dataset <br> **transform** (transform object, default=None):  transform to process input data <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions | Please arrange data in this way: <br> root/class_1/xxx.png <br> root/class_1/xxy.png <br> root/class_1/xxz.png <br> ... <br> root/class_n/123.png <br> root/class_n/nsdf3.png <br> root/class_n/asd932_.png <br> Please put images of different categories into different folders. | **In yaml file:** <br> dataset: <br> &ensp;&ensp; ImageFolder: <br> &ensp;&ensp;&ensp;&ensp; root: /path/to/root <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['ImageFolder'] (root=root,transform=transform, filter=None) |
| ImagenetRaw(data_path, image_list, transform, filter) | **data_path** (str): Root directory of dataset <br> **image_list** (str): data file, record image_names and their labels <br> **transform** (transform object, default=None):  transform to process input data <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions | Please arrange data in this way: <br> data_path/img1.jpg <br> data_path/img2.jpg <br> ... <br> data_path/imgx.jpg <br> dataset will read name and label of each image from image_list file, if user set image_list to None, it will read from data_path/val_map.txt automatically. | **In yaml file:** <br> dataset: <br> &ensp;&ensp; ImagenetRaw: <br> &ensp;&ensp;&ensp;&ensp; data_path: /path/to/image <br> &ensp;&ensp;&ensp;&ensp; image_list: /path/to/label <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['ImagenetRaw'] (data_path, image_list, transform=transform, filter=None) |
| COCORaw(root, img_dir, anno_dir, transform, filter) | **root** (str): Root directory of dataset <br> **img_dir** (str, default='val2017'): image file directory <br> **anno_dir** (str, default='annotations/instances_val2017.json'): annotation file directory <br> **transform** (transform object, default=None):  transform to process input data <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions | Please arrange data in this way: <br> /root/img_dir/1.jpg <br> /root/img_dir/2.jpg <br> ... <br> /root/img_dir/n.jpg <br> /root/anno_dir <br> **Now COCORaw just supports batch_size=1**| **In yaml file:** <br> dataset: <br> &ensp;&ensp; COCORaw: <br> &ensp;&ensp;&ensp;&ensp; root: /path/to/root <br> &ensp;&ensp; img_dir: /path/to/image <br> &ensp;&ensp; anno_dir: /path/to/annotation <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['COCORaw'] (root, img_dir, anno_dir, transform=transform, filter=None) <br> If anno_dir is not set, the dataset will use default label map |
| dummy(shape, low, high, dtype, label, transform, filter) | **shape** (list or tuple):support create multi shape tensors, use list of tuples for each tuple in the list, will create a such size tensor. <br> **low** (list or float, default=-128.):low out the tensor value range from[0, 1] to [0, low] or [low, 0] if low < 0, if float, will implement all tensors with same low value. <br> **high** (list or float, default=127.):high the tensor value by add all tensor element value high. If list, length of list should be same with shape list <br> **dtype** (list or str, default='float32'):support multi tensor dtype setting. If list, length of list should be same with shape list, if str, all tensors will use same dtype. dtype support 'float32', 'float16', 'uint8', 'int8', 'int32', 'int64', 'bool' <br> **label** (bool, default=False):whether to return 0 as label <br> **transform** (transform object, default=None): dummy dataset does not need transform. If transform is not None, it will ignore it. <br> **filter** (Filter objects, default=None): filter out examples according to specific conditions | This dataset is to construct a dataset from a specific shape, the value range is calculated from: low * stand_normal(0, 1) + high. | **In yaml file:** <br> dataset: <br> &ensp;&ensp; dummy: <br> &ensp;&ensp;&ensp;&ensp; shape: [3, 224, 224, 3] <br> &ensp;&ensp;&ensp;&ensp; low: 0.0 <br> &ensp;&ensp;&ensp;&ensp; high: 127.0 <br> &ensp;&ensp;&ensp;&ensp; dtype: float32 <br> &ensp;&ensp;&ensp;&ensp; label: False <br> **In user code:** <br> from lpot.data import DATASETS <br> datasets = DATASETS(framework) <br> dataset = datasets['dummy'] (shape, low, high, dtype, label, transform=None, filter=None) |


## User specific dataset

User can register their own dataset as follows:

```python
class Dataset(object):
    def __init__(self, args):
        # init code here

    def __getitem__(self, idx):
        # use idx to get data and label
        return data, label

    def __len__(self):
        return len

```

After defining the dataset class, user can pass it to quantizer.

```python
from lpot import Quantization, common
quantizer = Quantization(yaml_file)
quantizer.calib_dataloader = common.DataLoader(dataset) # user can pass more optional args to dataloader such as batch_size and collate_fn
quantizer.model = common.Model(graph)
quantizer.eval_func = eval_func
q_model = quantizer() 

```
